Welcome to houdini-logging-tools's documentation!
=================================================

The ``houdini-logging-tools`` package contains logging related utilities for logging in
`SideFX's Houdini <http://sidefx.com>`_.

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    adapters/index.rst
    handlers/index.rst

    api/modules
